@@ -555,7 +555,6 @@ static gint updateOutput(gpointer data)
 		GArray *quotes = stockdata->quotes;
 		PangoFontDescription *my_font = stockdata->my_font;
 		GdkGC *gc = stockdata->gc;
-		GdkGC *bg;
 		GdkRectangle update_rect;
 		PangoLayout *layout;
 		PangoRectangle logical_rect;
@@ -571,15 +570,12 @@ static gint updateOutput(gpointer data)
 		totalLoc = 0;
 		totalLen = 0;
 	
-		bg = gdk_gc_new (stockdata->pixmap);
-		gdk_gc_set_foreground( bg, &stockdata->gdkBGcolor );
+		gdk_gc_set_foreground( gc, &stockdata->gdkBGcolor );
 		gdk_draw_rectangle (stockdata->pixmap,
-				    bg, TRUE, 0,0,
+				    gc, TRUE, 0,0,
 				    drawing_area->allocation.width,
 				    drawing_area->allocation.height);
-		g_object_unref (bg);
-
-
+		
 		layout = stockdata->layout;
 		
 		for (i=0; i< stockdata->setCounter; i++) {
@@ -767,17 +763,15 @@ static gint updateOutput(gpointer data)
 	static void zipLeft(GtkWidget *widget, gpointer data) {
 		StockData *stockdata = data;
 		gboolean current;
-		gint i;
+		gint i, temp;
 
 		current = stockdata->props.scroll;
 		stockdata->props.scroll = TRUE;
-		stockdata->delta = 150;
+		temp = stockdata->delta;
+		stockdata->delta = 50;
 		stockdata->MOVE = 0;
-		/*for (i=0;i<151;i++) {
-			Repaint(stockdata);
-		}*/
 		Repaint(stockdata);
-		stockdata->delta = 2;
+		stockdata->delta = temp;
 		stockdata->props.scroll = current;
 	}
 
@@ -785,18 +779,15 @@ static gint updateOutput(gpointer data)
 	static void zipRight(GtkWidget *widget, gpointer data) {
 		StockData *stockdata = data;
 		gboolean current;
-		gint i;
+		gint i, temp;
 
 		current = stockdata->props.scroll;
 		stockdata->props.scroll = FALSE;
-		stockdata->delta = 150;
+		temp = stockdata->delta;
+		stockdata->delta = 50;
 		stockdata->MOVE = 0;
-		/*
-		for (i=0;i<151;i++) {
-			Repaint(stockdata);
-		}*/
 		Repaint(stockdata);
-		stockdata->delta = 2;
+		stockdata->delta = temp;
 		stockdata->props.scroll = current;
 	}
 
@@ -1458,11 +1449,11 @@ static gint updateOutput(gpointer data)
 
 		hbox = symbolManager(stockdata);
 
-		label = gtk_label_new_with_mnemonic (_("_Symbols"));
+		label = gtk_label_new (_("Symbols"));
 		gtk_notebook_append_page (GTK_NOTEBOOK (notebook), hbox, label);
-		label = gtk_label_new_with_mnemonic (_("_Behavior"));
+		label = gtk_label_new (_("Behavior"));
 		gtk_notebook_append_page (GTK_NOTEBOOK (notebook), vbox, label);
-		label = gtk_label_new_with_mnemonic (_("_Appearance"));
+		label = gtk_label_new (_("Appearance"));
 		gtk_notebook_append_page (GTK_NOTEBOOK (notebook), vbox2, label);
 		
 		gtk_widget_show_all(stockdata->pb);
@@ -1523,7 +1514,7 @@ static gint updateOutput(gpointer data)
 		access_stock = stockdata = g_new0 (StockData, 1);
 		stockdata->applet = GTK_WIDGET (applet);
 		stockdata->timeout = 0;
-		stockdata->delta = 2;
+		stockdata->delta = 1;
 		stockdata->vfshandle = NULL;
 		stockdata->configFileName = g_strconcat (g_getenv ("HOME"), 
 						         "/.gtik.conf", NULL);
@@ -1592,6 +1583,7 @@ static gint updateOutput(gpointer data)
 
 		gtk_widget_show (GTK_WIDGET (applet));
 		
+		gtk_widget_realize (stockdata->drawing_area);
 		create_gc(stockdata);
 
 		properties_set(stockdata,FALSE);
