@@ -14,7 +14,7 @@
 #include <gnome.h>
 #include <panel-applet.h>
 
-#include "weather.h"
+
 
 /* Radar map on by default. */
 #define RADARMAP
@@ -23,6 +23,8 @@ G_BEGIN_DECLS
  
 typedef struct _GWeatherApplet GWeatherApplet;
 typedef struct _GWeatherPrefs GWeatherPrefs;
+typedef struct _WeatherInfo WeatherInfo;
+typedef struct _WeatherLocation WeatherLocation;
 
 struct _GWeatherPrefs {
     WeatherLocation *location;
@@ -31,6 +33,8 @@ struct _GWeatherPrefs {
     gboolean use_metric;
     gboolean detailed;
     gboolean radar_enabled;
+    gboolean use_custom_radar_url;
+    gchar *radar;
 };
 
 struct _GWeatherApplet
@@ -40,7 +44,7 @@ struct _GWeatherApplet
 	
 	GtkWidget *box;	
 	GtkWidget *label;
-	GtkWidget *pixmap;
+	GtkWidget *image;
 	GtkTooltips *tooltips;
 	
 	PanelAppletOrient orient;
@@ -56,13 +60,12 @@ struct _GWeatherApplet
 	GtkWidget *pref_basic_detailed_btn;
 #ifdef RADARMAP
 	GtkWidget *pref_basic_radar_btn;
+	GtkWidget *pref_basic_radar_url_btn;
+	GtkWidget *pref_basic_radar_url_hbox;
+	GtkWidget *pref_basic_radar_url_entry;
 #endif /* RADARMAP */
 	GtkWidget *pref_basic_update_spin;
 	GtkWidget *pref_basic_update_btn;
-	GtkWidget *pref_net_proxy_btn;
-	GtkWidget *pref_net_proxy_url_entry;
-	GtkWidget *pref_net_proxy_user_entry;
-	GtkWidget *pref_net_proxy_passwd_entry;
 	GtkWidget *pref_tree;
 	
 	/* dialog stuff */
@@ -78,13 +81,13 @@ struct _GWeatherApplet
 	GtkWidget *cond_wind;
 	GtkWidget *cond_pressure;
 	GtkWidget *cond_vis;
-	GtkWidget *cond_pixmap;
+	GtkWidget *cond_image;
 	GtkWidget *forecast_text;
-	GtkWidget *radar_pixmap;
+	GtkWidget *radar_image;
 
-	GdkPixmap *dialog_pixmap;
+	GdkPixbuf *dialog_pixbuf;
 	GdkBitmap *dialog_mask;
-	GdkPixmap *applet_pixmap;
+	GdkPixbuf *applet_pixbuf;
 	GdkBitmap *applet_mask;
 };
 
